==> tencentcloud-sdk-java-3.1.900-sources.jar: com/tencentcloudapi/omics/v20221128/models/GetRunMetadataFileResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.omics.v20221128.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class GetRunMetadataFileResponse extends AbstractModel {

    /**
    * 文件预签名链接，一分钟内有效。
    */
    @SerializedName("CosSignedUrl")
    @Expose
    private String CosSignedUrl;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 文件预签名链接，一分钟内有效。 
     * @return CosSignedUrl 文件预签名链接，一分钟内有效。
     */
    public String getCosSignedUrl() {
        return this.CosSignedUrl;
    }

    /**
     * Set 文件预签名链接，一分钟内有效。
     * @param CosSignedUrl 文件预签名链接，一分钟内有效。
     */
    public void setCosSignedUrl(String CosSignedUrl) {
        this.CosSignedUrl = CosSignedUrl;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public GetRunMetadataFileResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public GetRunMetadataFileResponse(GetRunMetadataFileResponse source) {
        if (source.CosSignedUrl != null) {
            this.CosSignedUrl = new String(source.CosSignedUrl);
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "CosSignedUrl", this.CosSignedUrl);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.930-sources.jar: com/tencentcloudapi/omics/v20221128/models/GetRunMetadataFileResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.omics.v20221128.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class GetRunMetadataFileResponse extends AbstractModel {

    /**
    * 文件预签名链接，一分钟内有效。
    */
    @SerializedName("CosSignedUrl")
    @Expose
    private String CosSignedUrl;

    /**
    * 批量文件预签名链接，一分钟内有效。
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("CosSignedUrls")
    @Expose
    private String [] CosSignedUrls;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 文件预签名链接，一分钟内有效。 
     * @return CosSignedUrl 文件预签名链接，一分钟内有效。
     */
    public String getCosSignedUrl() {
        return this.CosSignedUrl;
    }

    /**
     * Set 文件预签名链接，一分钟内有效。
     * @param CosSignedUrl 文件预签名链接，一分钟内有效。
     */
    public void setCosSignedUrl(String CosSignedUrl) {
        this.CosSignedUrl = CosSignedUrl;
    }

    /**
     * Get 批量文件预签名链接，一分钟内有效。
注意：此字段可能返回 null，表示取不到有效值。 
     * @return CosSignedUrls 批量文件预签名链接，一分钟内有效。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public String [] getCosSignedUrls() {
        return this.CosSignedUrls;
    }

    /**
     * Set 批量文件预签名链接，一分钟内有效。
注意：此字段可能返回 null，表示取不到有效值。
     * @param CosSignedUrls 批量文件预签名链接，一分钟内有效。
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setCosSignedUrls(String [] CosSignedUrls) {
        this.CosSignedUrls = CosSignedUrls;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public GetRunMetadataFileResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public GetRunMetadataFileResponse(GetRunMetadataFileResponse source) {
        if (source.CosSignedUrl != null) {
            this.CosSignedUrl = new String(source.CosSignedUrl);
        }
        if (source.CosSignedUrls != null) {
            this.CosSignedUrls = new String[source.CosSignedUrls.length];
            for (int i = 0; i < source.CosSignedUrls.length; i++) {
                this.CosSignedUrls[i] = new String(source.CosSignedUrls[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "CosSignedUrl", this.CosSignedUrl);
        this.setParamArraySimple(map, prefix + "CosSignedUrls.", this.CosSignedUrls);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
